@@ -1,7 +1,7 @@
 from .activation import Swish, CReLU, Mish, Identity, SimpleSwish
 from .focal import FocalBCELoss
 from .drop_connect import DropConnect
-from .ada_group_norm import AdaGroupNorm
+from .ada_group_norm import ada_group_norm
 from .weight_standard_conv import WSConv2d
 from .utils import build_conv2d, ConvNormAct, SeparableConvNormAct, SeparableConv
 from .se_layer import SELayer
